% component_selection_v01.m
%
% Simple script to correlate each independent component with a condition
% A method mentioned in Formisano et al (2002, Neurocomputing)
% (More advanced methods are actually proposed in that article)
%
% Usage: Load script in Matlab, press 'Run'. If Matlab asks a question about the path, click button 'Add to path'.
% The script will ask for an *.rtc file containing the time courses of the
% independent components and for a design matrix file (*.sdm) with
% predictors.
%
% Requires Matlab and NeuroElf (www.neuroelf.net)
% HB, 24-03-16; latest update 28-03-16; Use for own risk

% read IC file, created by ICA module in BrainVoyager
[FileName, PathName] = uigetfile('*.rtc'); % get ICA-module generated time courses
ica = BVQXfile([PathName FileName]);
[FileName, PathName] = uigetfile('*.sdm'); % read design matrix file
sdm = BVQXfile([PathName FileName]);

% loop over (first 10) predictors and independent components
for j=1:sdm.NrOfPredictors
    figure
    subplot(11,1,1);
    cond = sdm.SDMMatrix(:,j);
    plot(cond)
    title(sdm.PredictorNames(j))
    for i=1:ica.NrOfPredictors
        counter = mod(i,10);
        if ((i > 10) & (counter==1))
            figure
            subplot(11,1,1);
            plot(cond)
            title(sdm.PredictorNames(j))
        end
        ic = ica.RTCMatrix(:,i);
        r=corrcoef(ic,cond);   % calculate correlation
        rlist(i) = r(1,2);
        if (counter == 0) 
            subplot(11,1,counter+11);
        else
        subplot(11,1,counter+1);
        end
        plot(ic); % plot ic time course
        title(['ic ' num2str(i) ', corr with PRT cond ' num2str(j) ': ' num2str(rlist(i))]);
        hold on;
    end
end